import pygame

from .baseobjects import Drawable, Text

class ChapterTransition(Drawable):
    def __init__(self, gamestate, text, seconds=2):
        super(ChapterTransition, self).__init__((0, 0), gamestate)

        self._anim_frame_timer = gamestate.fps * seconds

        font_size = 15 * gamestate.scale
        self.text = Text((0, 0), gamestate, text, font_size)
        text_rect = self.text.get_rect()
        text_pos = (
            (gamestate.screen_size[0] - text_rect[2]) / 2,
            (gamestate.screen_size[1] - text_rect[3]) / 2
        )
        self.text.position = text_pos

    def draw_on(self, surface, cam):
        self.text.draw_on(surface, cam)
    
    def update(self, dt):
        if self._anim_frame_timer > 0:
            self._anim_frame_timer -= 1
            if self._anim_frame_timer == 0:
                self.gamestate.transition_queue.pop()

    def get_rect(self):
        return pygame.Rect(self.position, self.gamestate.screen_size)